# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

<!-- insertion marker -->
## [0.4.2](https://github.com/csiro-hydroinformatics/geosdhydro/releases/tag/0.4.2) - 2025-10-22

<small>[Compare with 0.4.1](https://github.com/csiro-hydroinformatics/geosdhydro/compare/0.4.1...0.4.2)</small>

### Code Refactoring

- update duties to not include doc deploy. Also workaround to get over a previous botched `make release` ([31ce3b9](https://github.com/csiro-hydroinformatics/geosdhydro/commit/31ce3b986e460efd7e66bf8d39514ba13f1de7cc) by J-M).

## [0.4.1](https://github.com/csiro-hydroinformatics/geosdhydro/releases/tag/0.4.1) - 2025-10-22

<small>[Compare with 0.4.0](https://github.com/csiro-hydroinformatics/geosdhydro/compare/0.4.0...0.4.1)</small>

### Code Refactoring

- change the parameter name and default values for retrieving the subarea area from 'DArea2' to 'DArea' ([ac4e312](https://github.com/csiro-hydroinformatics/geosdhydro/commit/ac4e3126f6c5b372e39c45b6ad9e681f62e64727) by J-M). Request from James. Fixes: #6

## [0.4.0](https://github.com/csiro-hydroinformatics/geosdhydro/releases/tag/0.4.0) - 2025-09-10

<small>[Compare with 0.3.0](https://github.com/csiro-hydroinformatics/geosdhydro/compare/0.3.0...0.4.0)</small>

### Features

- optional custom names for nodes, links, subareas ([a6fa136](https://github.com/csiro-hydroinformatics/geosdhydro/commit/a6fa136a01dd5ef339986221278016761f93f6f6) by J-M). [Issue-5](https://github.com/csiro-hydroinformatics/geosdhydro/issues/5)
- Support some numeric types as inputs for path length and subarea area ([f773fcc](https://github.com/csiro-hydroinformatics/geosdhydro/commit/f773fcca17ed3f4dc408bbc7e86a33aec73954bd) by J-M).

## [0.3.0](https://github.com/csiro-hydroinformatics/geosdhydro/releases/tag/0.3.0) - 2025-08-08

<small>[Compare with 0.2.0](https://github.com/csiro-hydroinformatics/geosdhydro/compare/0.2.0...0.3.0)</small>

### Features

- customisable models for runoff and routing links #4 ([4ecc020](https://github.com/csiro-hydroinformatics/geosdhydro/commit/4ecc020e1fec78b79ea344a4e3ed569051307e81) by J-M).

## [0.2.0](https://github.com/csiro-hydroinformatics/geosdhydro/releases/tag/0.2.0) - 2025-08-07

<small>[Compare with 0.1.1](https://github.com/csiro-hydroinformatics/geosdhydro/compare/0.1.1...0.2.0)</small>

### Features

- customisable field names for the input shapefile. ([6c51ee3](https://github.com/csiro-hydroinformatics/geosdhydro/commit/6c51ee3b05966db14e7eb68ead46657f824eeddc) by J-M).

## [0.1.1](https://github.com/csiro-hydroinformatics/geosdhydro/releases/tag/0.1.1) - 2025-07-29

<small>[Compare with 0.1.0](https://github.com/csiro-hydroinformatics/geosdhydro/compare/0.1.0...0.1.1)</small>

### Bug Fixes

- check for LinkID unicity, see issue #1 ([b44ccc9](https://github.com/csiro-hydroinformatics/geosdhydro/commit/b44ccc9ce3d0fc590f4c07240b785f169b94ad1d) by J-M).

### Code Refactoring

- swift module under _internal, see #2 ([ad9519f](https://github.com/csiro-hydroinformatics/geosdhydro/commit/ad9519f915d718c6978a03f0fb83c869b1b10d7d) by J-M).

## [0.1.0](https://github.com/csiro-hydroinformatics/geosdhydro/releases/tag/0.1.0) - 2025-07-27

<small>[Compare with 0.0.1](https://github.com/csiro-hydroinformatics/geosdhydro/compare/0.0.1...0.1.0)</small>

### Features

- converter from shapefile / geopandas link specs to a swift json catchment structure ([53a9bbf](https://github.com/csiro-hydroinformatics/geosdhydro/commit/53a9bbfb3dae3b4046a229a601640232913b0537) by J-M).

## [0.0.1](https://github.com/csiro-hydroinformatics/geosdhydro/releases/tag/0.0.1) - 2025-07-27

<small>[Compare with first commit](https://github.com/csiro-hydroinformatics/geosdhydro/compare/b2d30e194a18e6409bb79bbd69d24276aaadd687...0.0.1)</small>
